summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp')
-rw-r--r--TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp24
1 files changed, 15 insertions, 9 deletions
diff --git a/TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp b/TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp
index c530661f515..d3d31499310 100644
--- a/TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp
+++ b/TAO/orbsvcs/orbsvcs/Shutdown_Utilities.cpp
@@ -1,9 +1,19 @@
// $Id$
-//ACE_RCSID(orbsvcs, Shutdown_Utilities, "$Id$")
-
#include "Shutdown_Utilities.h"
+ACE_RCSID(orbsvcs,
+ Shutdown_Utilities,
+ "$Id$")
+
+Shutdown_Functor::Shutdown_Functor (void)
+{
+}
+
+Shutdown_Functor::~Shutdown_Functor (void)
+{
+}
+
Service_Shutdown::Service_Shutdown (Shutdown_Functor& sf)
: functor_(sf)
{
@@ -25,21 +35,17 @@ Service_Shutdown::Service_Shutdown (Shutdown_Functor& sf, ACE_Sig_Set& which_sig
// declared the largest signal held in sigset_t, but we can't.
// So, for now, we'll make a possibly bold assumption that sigset_t
// will be at least four bytes. If somebody wants to use a signal
// greater than that, then they'll have to redefine TAO_ORBSVCS_MAXSIG.
//
// It would be even nicer if the register_handler() method just took
// an ACE_Sig_Set as an argument and handled all this stuff itself.
-//
-#ifndef TAO_ORBSVCS_MAXSIG
-# define TAO_ORBSVCS_MAXSIG 32
-#endif
-
+//
void
Service_Shutdown::set_signals (ACE_Sig_Set& which_signals)
{
// iterate over all the signals in which_signals and register them...
int did_register = 0;
- for (int i = 1; i < TAO_ORBSVCS_MAXSIG; i++)
+ for (int i = 1; i < ACE_NSIG; i++)
if (which_signals.is_member (i))
{
if (this->shutdown_.register_handler (i, this) == -1)
@@ -25,21 +35,17 @@ Service_Shutdown::Service_Shutdown (Shutdown_Functor& sf, ACE_Sig_Set& which_sig
// So, for now, we'll make a possibly bold assumption that sigset_t
// will be at least four bytes. If somebody wants to use a signal
-// greater than that, then they'll have to redefine TAO_ORBSVCS_MAXSIG.
+// greater than that, then they'll have to redefine ACE_NSIG.
//
// It would be even nicer if the register_handler() method just took